norm.data <- function(d,d.csize,feat1,feat2) {
  
  # summarize token sizes of feat2
  d.csize.feat2 <- ddply(d.csize, c(feat2),summarise,
                         N  = sum(N)
  )
  
  # add token sizes to data set  
  d <- merge(d,d.csize.feat2)
  # list of feat1 sorted according to frequency
  l.feat.sorted <- names(sort(-table(d[,feat1])))
  # sort data frame according to sorted feat1
  d[,feat1] <- factor(d[,feat1],levels=l.feat.sorted)
  
  # create data set with frequencies and fpm counts for feat1 according relative to calculated token sizes
  d.sum <- ddply(d, c(feat1,feat2,"N"), summarise, 
                 freq=length(get(feat1))
  )
  d.sum$fpm <- round(d.sum$freq / d.sum$N * 1000000,2)
  
  # return results as a list including the data sets `d` and `d.sum` als well as the sorted list `l.feat.sorted`
  return(list(d=d,d.sum=d.sum,l.feat.sorted=l.feat.sorted))
  
}

plot.line <- function(d,x,y,color,facet=NULL,title=NULL,xlab=NULL,ylab=NULL,group=NULL) {
  if (is.null(xlab)) xlab = ""
  if (is.null(ylab)) ylab = y
  if (is.null(ylab)) ylab = y
  if (is.null(group)) {p <- ggplot(d,aes(x=get(x),y=get(y),color=get(color)))}
  else {p <- ggplot(d,aes(x=get(x),y=get(y),color=get(color),group=get(group)))}
  p <- p +  geom_line(stat="identity") +
    xlab(xlab) + ylab(ylab) +
    scale_color_discrete(name=color) +
    theme(axis.text= element_text(size=14), 
          axis.title= element_text(size=14),
          legend.text=element_text(size=14),
          legend.title=element_text(size=14),
          title=element_text(size=14)) 
  if (!is.null(title)) p <- p + ggtitle(title)
  if (!is.null(facet)) p <- p + facet_wrap(as.formula(paste("~", facet))) 
  p
}

plot.bar <- function(d,x,y,pfill,facet=NULL,title=NULL,xlab=NULL,ylab=NULL) {
  if (is.null(xlab)) xlab = ""
  if (is.null(ylab)) ylab = y
  if (is.null(ylab)) ylab = y
  p <- ggplot(d,aes(x=get(x),y=get(y),fill=get(pfill))) +
    geom_bar(stat="identity",position="dodge") +
    xlab(xlab) + ylab(ylab) +
    scale_fill_discrete(name=pfill) +
    theme(axis.text= element_text(size=14), 
          axis.title= element_text(size=14),
          legend.text=element_text(size=14),
          legend.title=element_text(size=14),
          title=element_text(size=14)) 
  if (!is.null(title)) p <- p + ggtitle(title)
  if (!is.null(facet)) p <- p + facet_wrap(as.formula(paste("~", facet))) 
  p
}
